package com.example.smartlaby.screens

import android.annotation.SuppressLint
import android.os.Build
import androidx.annotation.RequiresApi
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.KeyboardArrowLeft
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.Icon
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.material3.TextFieldDefaults
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.focus.FocusDirection
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.LocalFocusManager
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavHostController
import kotlinx.coroutines.delay
import kotlin.time.Duration.Companion.seconds

@OptIn(ExperimentalMaterial3Api::class)
@RequiresApi(Build.VERSION_CODES.O)
@SuppressLint("RememberReturnType")
@Composable
fun ConfirmationEmail (navController: NavHostController){
    val focusManager = LocalFocusManager.current
    val (code1, setCode1) = remember { mutableStateOf("") }
    val (code2, setCode2) = remember { mutableStateOf("") }
    val (code3, setCode3) = remember { mutableStateOf("") }
    val (code4, setCode4) = remember { mutableStateOf("") }
    Column(
        modifier = Modifier
            .fillMaxSize()
            .background(Color(0xFFffffff))
            .padding(horizontal = 20.dp)
    ){}
    LaunchedEffect(
        key1 = code1,
    ) {
        if (code1!="") {
            focusManager.moveFocus(
                focusDirection = FocusDirection.Next,
            )
        }
    }
    LaunchedEffect(
        key1 = code2,
    ) {
        if (code2!="") {
            focusManager.moveFocus(
                focusDirection = FocusDirection.Next,
            )
        }
    }
    LaunchedEffect(
        key1 = code3,
    ) {
        if (code3!="") {
            focusManager.moveFocus(
                focusDirection = FocusDirection.Next,
            )
        }
    }
    LaunchedEffect(
        key1 = code4,
    ) {
        if (code4!="") {
            focusManager.moveFocus(
                focusDirection = FocusDirection.Next,
            )
        }
    }
    Column(
        modifier = Modifier
            .padding(horizontal = 20.dp)
            .padding(top = 24.dp)
    )
    {
        Button(onClick = { navController.navigate("NewPassword") },
            modifier = Modifier
                .size(height = 32.dp, width = 32.dp),
            shape = RoundedCornerShape(8.dp),
            colors = ButtonDefaults.buttonColors(
                containerColor = Color(0xFFF5F5F9)
            )) {

            Icon(
                modifier = Modifier.size(height = 20.dp, width = 20.dp),
                imageVector = Icons.Default.KeyboardArrowLeft,
                contentDescription = "icon",
                tint = Color.Red
            )
        }
    }
    Column(
        modifier = Modifier.fillMaxSize(),
        verticalArrangement = Arrangement.Center
    ) {
        Text(
            text = "Введите код из E-mail ",
            fontSize = 17.sp,
            fontWeight = FontWeight.Bold,
            modifier = Modifier.fillMaxWidth(1f),
            textAlign = TextAlign.Center
        )
        Row(
            horizontalArrangement = Arrangement.Center,
            modifier = Modifier.fillMaxWidth(1f)
                .padding(top = 25.dp),
        ){
            TextField(
                value = code1,
                onValueChange = {part ->
                    if(part.length >1 && part.isNotEmpty())
                        setCode1(part.substring(0,1))
                    else
                        setCode1(part)
                },
                modifier = Modifier
                    .padding(end = 16.dp)
                    .size(55.dp),
                maxLines = 1,
                singleLine = true,
                textStyle = TextStyle(
                    fontSize = 18.sp,
                    textAlign = TextAlign.Center
                ),
                keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Number),
                shape = RoundedCornerShape(13.dp),
                colors = TextFieldDefaults.textFieldColors(
                    containerColor = Color(0xFFF5F5F9),
                    focusedIndicatorColor = Color(0xFFF5F5F9),
                    unfocusedIndicatorColor = Color(0xFFF5F5F9),
                    cursorColor = Color.Black,
                    unfocusedPlaceholderColor = Color(0xFF939396),
                    disabledTextColor = Color.Transparent,
                    disabledIndicatorColor = Color.Transparent
                )
            )
            TextField(
                value = code2,
                onValueChange = {part ->
                    if(part.length >1 && part.isNotEmpty())
                        setCode2(part.substring(0,1))
                    else
                        setCode2(part)
                },
                modifier = Modifier
                    .padding(end = 16.dp)
                    .size(55.dp),
                maxLines = 1,
                singleLine = true,
                textStyle = TextStyle(
                    fontSize = 18.sp,
                    textAlign = TextAlign.Center
                ),
                keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Number),
                shape = RoundedCornerShape(13.dp),
                colors = TextFieldDefaults.textFieldColors(
                    containerColor = Color(0xFFF5F5F9),
                    focusedIndicatorColor = Color(0xFFF5F5F9),
                    unfocusedIndicatorColor = Color(0xFFF5F5F9),
                    cursorColor = Color.Black,
                    unfocusedPlaceholderColor = Color(0xFF939396),
                    disabledTextColor = Color.Transparent,
                    disabledIndicatorColor = Color.Transparent
                )
            )
            TextField(
                value = code3,
                onValueChange = {part ->
                    if(part.length >1 && part.isNotEmpty())
                        setCode3(part.substring(0,1))
                    else
                        setCode3(part)
                },
                modifier = Modifier
                    .padding(end = 16.dp)
                    .size(55.dp),
                maxLines = 1,
                singleLine = true,
                textStyle = TextStyle(
                    fontSize = 18.sp,
                    textAlign = TextAlign.Center
                ),
                shape = RoundedCornerShape(13.dp),
                keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Number),
                colors = TextFieldDefaults.textFieldColors(
                    containerColor = Color(0xFFF5F5F9),
                    focusedIndicatorColor = Color(0xFFF5F5F9),
                    unfocusedIndicatorColor = Color(0xFFF5F5F9),
                    cursorColor = Color.Black,
                    unfocusedPlaceholderColor = Color(0xFF939396),
                    disabledTextColor = Color.Transparent,
                    disabledIndicatorColor = Color.Transparent
                )
            )
            TextField(
                value = code4,
                onValueChange = {part ->
                    if(part.length >1 && part.isNotEmpty())
                        setCode4(part.substring(0,1))
                    else
                        setCode4(part)
                },
                modifier = Modifier
                    .size(55.dp),
                maxLines = 1,
                singleLine = true,
                textStyle = TextStyle(
                    fontSize = 18.sp,
                    textAlign = TextAlign.Center
                ),
                keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Number),
                shape = RoundedCornerShape(13.dp),
                colors = TextFieldDefaults.textFieldColors(
                    containerColor = Color(0xFFF5F5F9),
                    focusedIndicatorColor = Color(0xFFF5F5F9),
                    unfocusedIndicatorColor = Color(0xFFF5F5F9),
                    cursorColor = Color.Black,
                    unfocusedPlaceholderColor = Color(0xFF939396),
                    disabledTextColor = Color.Transparent,
                    disabledIndicatorColor = Color.Transparent
                )
            )
        }
        Column(
        ) {
            var ticks by remember { mutableStateOf(60) }
            LaunchedEffect(Unit) {
                while(true) {
                    if(ticks > 0){
                        delay(1.seconds)
                        ticks--
                    }
                    else break
                }
            }
            Text(
                text = "Отправить код повторно можно\r\nбудет через ${ticks} секунд",
                fontSize = 15.sp,
                modifier = Modifier
                    .fillMaxWidth(1f)
                    .padding(top = 10.dp),
                textAlign = TextAlign.Center,
                color = Color(0xFF939396),
                lineHeight = 20.sp)
        }

    }

}