package com.example.smartlaby.screens

import android.annotation.SuppressLint
import androidx.compose.foundation.BorderStroke
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.material3.TextFieldDefaults
import androidx.compose.runtime.Composable
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavHostController

@OptIn(ExperimentalMaterial3Api::class)
@SuppressLint("RememberReturnType")
@Composable
fun LogApp (navController: NavHostController){
    val email = remember { mutableStateOf("") }
    Column(
        modifier = Modifier.fillMaxSize()
            .background(Color(0xFFffffff))
            .padding(horizontal = 20.dp)
    )
    {
        Text(
            "🖐 Добро пожаловать! ",
            fontSize = 28.sp,
            color = Color(0xFF000000),
            fontWeight = FontWeight.Bold,
            modifier = Modifier.padding(top = 103.dp)
        )
        Text(
            "Войдите, чтобы пользоваться функциями приложения ",
            fontSize = 18.sp,
            color = Color(0xFF000000),
            modifier = Modifier.padding(top = 20.dp)
        )
        Text(
            "Вход по E-mail ",
            fontSize = 14.sp,
            color = Color(0xFF7E7E9A),
            modifier = Modifier.padding(top = 64.dp)
        )
        TextField(
            value = email.value,
            onValueChange = { newText -> email.value = newText },
            modifier = Modifier.padding(top = 5.dp).fillMaxWidth(1f),
            maxLines = 1,
            singleLine = true,
            shape = RoundedCornerShape(13.dp),
            colors = TextFieldDefaults.textFieldColors(
                containerColor = Color(0xFFF5F5F9),
                focusedIndicatorColor = Color(0xFFF5F5F9),
                unfocusedIndicatorColor = Color(0xFFF5F5F9),
                cursorColor = Color.Black,
                unfocusedPlaceholderColor = Color(0xFF939396)
            ),
            placeholder = { Text("example@mail.ru ") }
        )
        Button(
            onClick = {navController.navigate("ConfirmationEmail ")},
            modifier = Modifier
                .fillMaxWidth(1f)
                .padding(top = 30.dp)
                .height(55.dp),
            enabled = email.value.isNotEmpty(),
            shape = RoundedCornerShape(15.dp),
            colors = ButtonDefaults.buttonColors(
                containerColor = Color(0xFF1A6FEE),
                disabledContainerColor = Color(0xFFC9D4FB)
            )
        ) {
            Text(text = "Далее ", fontSize = 20.sp, color = Color(0xFFffffff))
        }
    }
    Column(
        verticalArrangement = Arrangement.Bottom
    ) {
        Text(
            "Или войдите с помощью ",
            modifier = Modifier.fillMaxWidth().padding(bottom = 20.dp),
            textAlign = TextAlign.Center,
            fontSize = 15.sp,
            color = Color(0xFF939396)
        )
        Button(
            onClick = {},
            modifier = Modifier
                .padding(bottom = 56.dp)
                .padding(start = 20.dp, end = 20.dp)
                .fillMaxWidth(1f)
                .height(60.dp),
            shape = RoundedCornerShape(15.dp),
            colors = ButtonDefaults.buttonColors(containerColor = Color(0xFFffffff)),
            border = BorderStroke(
                1.dp, color = Color(0xFFEBEBEB)
            )
        ) {
            Text(
                text = "Войти с Яндекс ", fontSize = 20.sp,
                color = Color(0xFF000000),
                fontWeight = FontWeight.Bold
            )
        }
    }


}